Module: Benchmark::Perf
- Defined in:
- lib/benchmark/perf.rb,
lib/benchmark/perf/clock.rb,
lib/benchmark/perf/stats.rb,
lib/benchmark/perf/version.rb,
lib/benchmark/perf/execution.rb,
lib/benchmark/perf/iteration.rb,
lib/benchmark/perf/cpu_result.rb,
lib/benchmark/perf/ips_result.rb
Defined Under Namespace
Modules: Clock, Execution, Iteration, Stats Classes: CPUResult, IPSResult
Constant Summary collapse
- VERSION =
"0.6.0"
Class Method Summary collapse
-
.cpu(**options, &work) ⇒ Array[Float, Float]
Measure execution time(a.k.a cpu time) of a given work.
-
.ips(**options, &work) ⇒ Array[Integer, Integer, Integer, Float]
Measure iterations a work could take in a second.
Class Method Details
.cpu(**options, &work) ⇒ Array[Float, Float]
Measure execution time(a.k.a cpu time) of a given work
43 44 45 |
# File 'lib/benchmark/perf.rb', line 43 def cpu(**, &work) Execution.run(**, &work) end |
.ips(**options, &work) ⇒ Array[Integer, Integer, Integer, Float]
Measure iterations a work could take in a second
23 24 25 |
# File 'lib/benchmark/perf.rb', line 23 def ips(**, &work) Iteration.run(**, &work) end |